#
# spec file for package guile-gcrypt
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           guile-gcrypt
Version:        0.4.0
Release:        1.8
Summary:        Cryptography library for Guile using Libgcrypt
License:        GPL-3.0-or-later
Group:          Development/Libraries/Other
URL:            https://notabug.org/cwebber/guile-gcrypt
Source0:        https://notabug.org/cwebber/%{name}/archive/v%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  guile-devel >= 2.0.10
BuildRequires:  libgcrypt-devel
BuildRequires:  pkg-config
BuildRequires:  texinfo
Requires:       guile >= 2.0.10
# guile-gcrypt needs /usr/lib64/libgcrypt.so (without version number)
Requires:       libgcrypt-devel
Requires(pre):  %{install_info_prereq}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Guile-Gcrypt provides a Guile 2.x interface to a subset of the GNU
Libgcrypt crytographic library. It provides modules for cryptographic
hash functions, message authentication codes (MAC), public-key cryptography,
strong randomness, and more. It is implemented using the foreign function
interface (FFI) of Guile.

%prep
%setup -q -n %{name}

%build
./bootstrap.sh
%configure
make # non-parallel for boo#1170378

%install
make install %{_smp_mflags} DESTDIR=%{buildroot}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/guile-gcrypt.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/guile-gcrypt.info.gz

%files
%defattr(-,root,root,-)
%doc AUTHORS README
%license COPYING
%{_datadir}/guile
%{_infodir}/guile-gcrypt*
%{_libdir}/guile

%changelog
* Thu Dec  1 2022 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to 0.4.0:
  * ‘base64-encode’ and ‘base64-decode’ now let you optionally control padding
  * New supported algorithms added to (gcrypt hash)
  * New supported algorithms added to (gcrypt mac)
  * Improvements and fixes to the manual
- Remove no longer needed rpmlintrc
* Fri Nov  6 2020 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to 0.3.0:
  * ‘sexp->canonical-sexp->sexp’ now accepts integers
  * (gcrypt common) exports ‘error/’ constants and error handling procedures
  * ‘verify’ now throws upon errors other than ‘error/bad-signature’
  * (gcrypt hmac) and (gcrypt hash) export bindings for their syntax literals
  * New ‘hash-algorithm-name’ and ‘mac-algorithm-name’ procedures
* Mon Jul  6 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Build non-parallel for reproducible builds (boo#1170378)
* Mon Jan 13 2020 Jonathan Brielmaier <jbrielmaier@suse.de>
- Make guile-gcrypt-rpmlintrc compatible with Guile 3.0
* Thu Dec 19 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Add guile-gcrypt-rpmlintrc as source to the spec file
* Tue Dec 17 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 0.2.1:
  * libgcrypt is now always properly initialized (https://bugs.gnu.org/37616)
  * (gcrypt base64) no longer imports (rnrs)
- Add guile-gcrypt-rpmlintrc to silence false positives
* Mon Sep 16 2019 Jonathan Brielmaier <jbrielmaier@suse.com>
- Update to version 0.2.0:
  * (gcrypt hash) now exposes all the algorithms supported by Libgcrypt
  * (guix mac) now exposes all the MAC algorithms, not just HMAC
  * (guix hmac) is deprecated in favor of (guix mac)
  * Guile-Gcrypt can now be compiled with Guile 2.9 (future 3.0)
  * Guile-Gcrypt can now be cross-compiled
* Mon Jul 22 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- require guile >= 2.0.10 because it implements (ice-9 hash-table)
* Mon Aug 27 2018 jbrielmaier@suse.de
- guile-gcrypt at version 0.1.0
